<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>OutputJACKFactory</name>
    <message>
        <location filename="../outputjackfactory.cpp" line="30"/>
        <source>JACK Plugin</source>
        <translation>Wtyczka JACK</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="53"/>
        <source>About Jack Output Plugin</source>
        <translation>O wtyczce wyjściowej Jack</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="54"/>
        <source>Qmmp Jack Output Plugin</source>
        <translation>Wtyczka wyjściowa Jack dla Qmmp</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="55"/>
        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>Napisana przez: Jurij Žuravljov &lt;slalkerg@gmail.com&gt;</translation>
    </message>
</context>
</TS>
